@@ -4,6 +4,7 @@ mod mysql;
 mod postgres;
 mod redis;
 mod tidb;
+mod tikv;
 
 pub use cassandra::Cassandra;
 pub use dynamodb::DynamoDB;
@@ -11,6 +12,7 @@ pub use mysql::MySQL;
 pub use postgres::PostgreSQL;
 pub use redis::Redis;
 pub use tidb::TiDB;
+pub use tikv::TiKV;
 
 #[macro_export]
 macro_rules! svec {
